@@ -1,4 +1,5 @@
-/* Copyright(C) 2005,2006,2007,2008 Stefan Siegl <stesie@brokenpipe.de>
+/* vim: noexpandtab sts=2 ts=8 sw=2
+ * Copyright(C) 2005,2006,2007,2008 Stefan Siegl <stesie@brokenpipe.de>
  * taxbird - free program to interface with German IRO's Elster/Coala
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +22,7 @@
 #endif
 
 #include <gnome.h>
-#include <libgtkhtml/gtkhtml.h>
+#include <gtkhtml/gtkhtml.h>
 #include <sys/wait.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -47,13 +48,15 @@ static pid_t taxbird_export_launch_subproc(int *to, int *from);
 typedef pid_t (* taxbird_export_subproc) (int *to, int *from);
 
 /* ask the user whether the exported data is okay */
-static void taxbird_export_ask_user(HtmlDocument *doc,
+static void taxbird_export_ask_user(GtkWidget *html,
 				    SCM data, SCM proto_fn, SCM softpse_fn);
 
 /* launch the given command CMD (whether CMD may even contain arguments)
  * RETURN: pid of child on success, -1 on failure */
 static pid_t taxbird_export_launch_command(const char *cmd, int *to, int *fr);
 
+extern int geier_iso_to_utf8(const unsigned char *input, const size_t inlen,
+			     unsigned char **output, size_t *outlen);
 
 static int
 taxbird_xsltify_text(geier_context *context,
@@ -140,25 +143,25 @@ taxbird_export(int testcase)
     return;
   }
 
-  /* now convert xslt-result to HtmlDocument */
-  HtmlDocument *doc = html_document_new();
-  if(! doc) {
-    taxbird_dialog_error(NULL, _("Unable to allocate HtmlDocument."));
-    return;
-  }
-
-  if(! html_document_open_stream(doc, "text/html")) {
-    html_document_clear(doc);
-    taxbird_dialog_error(NULL, _("Unable to call open_stream"
-				 "on allocated HtmlDocument."));
-    return;
-  }
-
-  html_document_write_stream(doc, (const char *) data_xslt, data_xslt_len);
-  html_document_close_stream(doc);
+  /* convert output to UTF-8 needed by GtkHTML */
+  unsigned char *data_xslt_utf8;
+  size_t data_xslt_utf8_len;
 
+  geier_iso_to_utf8(data_xslt, data_xslt_len, &data_xslt_utf8, 
+		    &data_xslt_utf8_len);
   free(data_xslt);
 
+  /* now convert xslt-result to GtkHTML */
+  GtkWidget *doc = gtk_html_new_from_string
+	((const char *) data_xslt_utf8, data_xslt_utf8_len);
+
+  if(! doc) {
+    taxbird_dialog_error(NULL, _("Unable to allocate GtkHTML widget."));
+    return;
+  }
+
+  free(data_xslt_utf8);
+
   /* automatically fill protocol-store widget (which isn't filled by glade) **/
   taxbird_guile_eval_file("taxbird.scm");
   SCM fn = scm_call_1(scm_c_lookup_ref("tb:get-proto-filename"),
@@ -256,7 +259,12 @@ taxbird_export_bottom_half(GtkWidget *confirm_dlg)
       return 1;
     }
 
-    write(fd, data_text, data_text_len);
+    if(write(fd, data_text, data_text_len) != data_text_len) {
+      taxbird_dialog_error(confirm_dlg, _("Unable to write to Coala-XML file."));
+      geier_context_free(ctx);
+      free(data_text);
+      return 1;
+    }
     close(fd);
   }
 
@@ -371,12 +379,18 @@ taxbird_export_bottom_half(GtkWidget *confirm_dlg)
   }
 
   if(fd_to_lpr >= 0) {
-    write(fd_to_lpr, data_xslt, data_xslt_len);
+    if(write(fd_to_lpr, data_xslt, data_xslt_len) != data_xslt_len) {
+      taxbird_dialog_error(confirm_dlg,
+			   _("Failed to write to print-helper pipe."));
+    }
     close(fd_to_lpr);
   }
 
   if(fd_to_protofile >= 0) {
-    write(fd_to_protofile, data_xslt, data_xslt_len);
+    if(write(fd_to_protofile, data_xslt, data_xslt_len) != data_xslt_len) {
+      taxbird_dialog_error(confirm_dlg,
+			   _("Failed to write to protocol file."));
+    }
     close(fd_to_protofile);
   }
 
@@ -411,6 +425,9 @@ taxbird_export_call_backend(int test)
 {
   g_return_val_if_fail(taxbird_current_form, SCM_BOOL(0));
 
+  /* recalculate the whole sheet */
+  scm_call_1(taxbird_current_form->dataset_recalc, taxbird_document_data);
+
   /* call exporter function of current template */
   return scm_call_2(taxbird_current_form->dataset_export,
 		    taxbird_document_data, SCM_BOOL(test));
@@ -520,7 +537,7 @@ taxbird_export_launch_subproc(int *to, int *from)
 
 /* show the export druid and return */
 static void
-taxbird_export_ask_user(HtmlDocument *doc, SCM data,
+taxbird_export_ask_user(GtkWidget *doc, SCM data,
 			SCM fn, SCM softpse_fn)
 {
   /* GtkWidget *confirm_dlg = create_dlgExportConfirmation(); */
@@ -532,9 +549,7 @@ taxbird_export_ask_user(HtmlDocument *doc, SCM data,
                                            "scroll_htmlview");
   g_return_if_fail(scroll);
 
-  GtkWidget *htmlview = html_view_new();
-  gtk_container_add(GTK_CONTAINER(scroll), htmlview);
-  html_view_set_document(HTML_VIEW(htmlview), doc);
+  gtk_container_add(GTK_CONTAINER(scroll), doc);
 
   g_object_set_data_full(G_OBJECT(confirm_dlg), "data", 
 			 (void*) scm_gc_protect_object(data),
